@@ -2,7 +2,7 @@
 ## generate data from a negative binomial regression
 #' @export
 node_negative_binomial <- function(data, parents, formula=NULL, betas,
-                                   intercept, theta) {
+                                   intercept, theta, link="log") {
 
   if (!data.table::is.data.table(data)) {
     data.table::setDT(data)
@@ -15,10 +15,15 @@ node_negative_binomial <- function(data, parents, formula=NULL, betas,
     data <- as.data.frame(data[, parents, with=FALSE])
   }
 
-  eta <- intercept +
-    rowSums(mapply("*", data, betas))
+  eta <- intercept + rowSums(mapply("*", data, betas))
 
-  out <- stats::rnbinom(n=length(eta), mu=exp(eta), size=theta)
+  if (link=="log") {
+    eta <- exp(eta)
+  } else if (link=="sqrt") {
+    eta <- eta^2
+  }
+
+  out <- stats::rnbinom(n=length(eta), mu=eta, size=theta)
 
   return(out)
 }
